@@ -15,6 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
+
 #include <glib.h>
 #include "at_track.h"
 #include "at_clip.h"
@@ -397,6 +398,30 @@ at_clip_delayed_update (gpointer data)
   return (FALSE);
 }
 
+/* returns the length of the longest track */
+gint
+at_clip_get_composite_length (Clip *clip)
+{
+    GSList *list;
+    Track *track;
+    gint clip_length = 0;
+
+    list = clip->tracks;
+
+    while (list) {
+	track = (Track *) list->data;
+
+	if (!track->is_composite) {
+	    if (track->length > clip_length) {
+		clip_length = track->length;
+	    }
+	}
+
+	list = list->next;
+    }
+
+    return (clip_length);
+}
 
 void
 at_clip_new_cmd_callback (GtkWidget *widget, gpointer data)
@@ -409,7 +434,7 @@ at_clip_new_cmd_callback (GtkWidget *widget, gpointer data)
   view = at_view_new (clip);
 
   /* create a track to view the composite on */
-  track = at_track_new (view->clip->ID, 0, 200, AT_RL, "Composite", 1.0, 0);
+  track = at_track_new (view->clip->ID, 0, 0, AT_RL, "Composite", 1.0, 0);
   at_clip_add_track (view->clip, track, 
 		     at_clip_get_track_index (view->clip,
 					      view->clip->active_track));
@@ -422,7 +447,7 @@ at_clip_new_cmd_callback (GtkWidget *widget, gpointer data)
   track->is_composite = TRUE;
   
   /* create a first track for recording on */
-  track = at_track_new (view->clip->ID, 0, 200, AT_RL, "New Track", 1.0, 0);
+  track = at_track_new (view->clip->ID, 0, 0, AT_RL, "New Track", 1.0, 0);
   at_clip_add_track (view->clip, track, 
 		     at_clip_get_track_index (view->clip,
 					      view->clip->active_track));
