@@ -1,3 +1,21 @@
+/* Audiotechque -- Multitrack Mixer and Audio manipulation program
+ * Copyright (C) 1997-1998 Larry Ewing and Ian Main
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <gtk/gtk.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -235,7 +253,7 @@ at_track_new_cmd_callback (GtkWidget *widget, gpointer data)
 
   /* FIXME: need to make sure we handle the pathological cases... */
   /* FIXME: we need to build a new_track dialog here... :) */
-  track = at_track_new (view->clip->ID, 0, 200, AT_RL, "New Track", 1.0, 0);
+  track = at_track_new (view->clip->ID, 0, 0, AT_RL, "New Track", 1.0, 0);
   
   at_clip_add_track (view->clip, track, 
 		     at_clip_get_track_index (view->clip,
@@ -256,8 +274,6 @@ at_track_delete_cmd_callback (GtkWidget *widget, gpointer data)
     View *view;
     Track *track = NULL;
     
-    
-    
     /* FIXME this is ugly, but it's relatively sane from the moment I think.
        god I am writting some ugly code right now... --Larry */
     if (data != NULL)
@@ -269,13 +285,14 @@ at_track_delete_cmd_callback (GtkWidget *widget, gpointer data)
 	    /* can't delete the composite */
 	    if (track->is_composite)
 		return;
+
+	    at_track_mark_dirty (track, AT_TRACK_CHANGED_DELETED);
 	    
+	    /* we just remove it from the view here.  We don't actually
+	       delete it till we're done subtracting it from the composite. */
 	    at_clip_remove_track (view->clip, view->clip->active_track);
-	    at_track_delete (track);
 	}
     
-    /* set dirty flag for clip so it will be remixed */
-    view->clip->dirty++;
     at_views_update (view->clip->ID);
 }
 
@@ -345,6 +362,8 @@ void
 at_track_record_done (Clip *clip)
 {
     Track *track;
+    /* the default */
+    TrackChange change = AT_TRACK_CHANGED_MULTIPLE;
 
     /* ignore most of the crap in here, it's just test stuff */
     track = at_track_get_ID (clip->active_track);
@@ -353,6 +372,11 @@ at_track_record_done (Clip *clip)
 	AudioRegion *old;
 	
 	old = track->data;
+
+	/* If the track was of 0 length before, we can just add it to the composite. */
+	if (old->length == 0)
+	    change = AT_TRACK_CHANGED_NEW_TRACK;
+
 	track->data = region_new_from_file (record_track,
 					    at_type_bytes (track->type));
 	if (!track->data) {
@@ -369,7 +393,7 @@ at_track_record_done (Clip *clip)
     }
     
     /* track->preview_dirty = TRUE; */
-    at_track_mark_dirty (track, AT_TRACK_CHANGED_NEW_TRACK);
+    at_track_mark_dirty (track, change);
     at_track_build_preview (track);
     at_track_update_preview (track);
 }
@@ -382,26 +406,29 @@ at_track_mute_cmd_callback (GtkWidget *widget, gpointer *data)
     gint track_ID = (gint) data;
     Track *track;
     Clip *clip;
+    gint mute;
 
-    /* FIXME the suspend flag is because of the set state in the creation
-       routine it's not well implemented, but I don't care right now :) */
-    
     track = at_track_get_ID (track_ID);
+
+    if (track->is_composite) 
+	return;
     
     if (GTK_TOGGLE_BUTTON (widget)->active) {
       g_print ("muting track %d\n", track_ID);
-      track->mute = TRUE;
+      mute = TRUE;
     } else {
       g_print ("un-muting track %d\n", track_ID);
-      track->mute = FALSE;
+      mute = FALSE;
     }
-    
-    /* this one is muted now, we have to remix. */
+
+    if (mute == TRUE)
+	at_track_mark_dirty (track, AT_TRACK_CHANGED_MUTED);
+    else
+	at_track_mark_dirty (track, AT_TRACK_CHANGED_UNMUTED);
+
     clip = at_clip_get_ID (track->clip_ID);
-    clip->dirty = TRUE;
-    
-    if (!track->is_composite) 
-      at_delay (1000, at_clip_delayed_update, clip);
+
+    at_delay (1000, at_clip_delayed_update, clip);
 }
 
 static void 
@@ -426,11 +453,21 @@ at_track_volume_changed_cmd_callback (GtkWidget *widget, gpointer *data)
     at_track_adjust_volume_of_preview (track, track->volume, volume);
     at_track_update_preview (track);
 
+    /* we're doing a bit of a performance hack here.
+       If the volume has already been changed, then
+       track->changed will be AT_TRACK_CHANGED_VOLUME, 
+       so we just leave it, and wait for the idle mix 
+       to be called. */
+    if (track->change != AT_TRACK_CHANGED_VOLUME) {
+	track->old_volume = track->volume;
+	at_track_mark_dirty(track, AT_TRACK_CHANGED_VOLUME);
+    }
+
     track->volume = volume;
-    at_track_mark_dirty(track, AT_TRACK_CHANGED_VOLUME);
 
     clip = at_clip_get_ID (track->clip_ID);
-    
+
+    /* a delayed update, so mixing does not cause poor interactivity. */
     if (!track->is_composite) 
       at_delay (1000, at_clip_delayed_update, clip);
 }
