@@ -4,21 +4,7 @@
 #include "at_type.h"
 #include "region.h"
 #include "at_view.h"
-
-/* these are to make us able to do 'smart' mixing.  For instance, there
-   is no need to mix all tracks when just adding a new one. */
-
-typedef enum
-{
-    AT_TRACK_CHANGED_NONE,
-    AT_TRACK_CHANGED_VOLUME,
-    AT_TRACK_CHANGED_DELETED,
-    AT_TRACK_CHANGED_NEW_TRACK,
-    AT_TRACK_CHANGED_OFFSET,
-    /* if multiple things have been changed, 
-       we are unable to do tricky mixing. */
-    AT_TRACK_CHANGED_MULTIPLE
-} TrackChange;
+#include "at_enums.h"
 
 
 typedef struct _Track Track;
@@ -54,6 +40,11 @@ struct _Track
 
     gint dirty;                 /* Count of how many times track has been changed */
     TrackChange change;         /* Original event to modify track  */
+    gfloat old_volume;          /* For remixing when the volume is changed.  It's a bit of a
+				   performance hack, but it does work well. */
+    gint delete_me;             /* When track requires deletion, and
+				   this is marked TRUE, the delete is done
+				   at the end of the streamlined mix (if appropriate)*/
     
     gint ID;                    /* unique ID                */
     gint clip_ID;               /* ID of clip owner         */
