@@ -1,3 +1,21 @@
+/* Audiotechque -- Multitrack Mixer and Audio manipulation program
+ * Copyright (C) 1997-1998 Larry Ewing and Ian Main
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <stdio.h>
 #include <errno.h>
 #include <sys/types.h>
@@ -12,7 +30,7 @@ AudioRegion *
 region_new (size_t length, gint bps)
 {
   AudioRegion *new;
-
+  gchar c = 2;
   gint fd;
 
   new = (AudioRegion *) g_malloc (sizeof (AudioRegion));
@@ -32,10 +50,12 @@ region_new (size_t length, gint bps)
 	     new->filename,
 	     g_strerror (errno));
   
-  if (lseek(fd, length * bps -1, SEEK_SET) == -1)
-    g_warning ("lseek: %s", g_strerror (errno));
-  if (write(fd, "\0", 1) != 1)
-    g_warning ("write: %s", g_strerror (errno));
+  if (length > 0) {
+      if (lseek(fd, length * bps -1, SEEK_SET) == -1)
+	  g_warning ("lseek: %s", g_strerror (errno));
+      if (write(fd, &c, sizeof (gchar)) != 1)
+	  g_warning ("write: %s", g_strerror (errno));
+  }
 
   new->fd = fd;
 
@@ -151,7 +171,7 @@ region_resize (AudioRegion *src, size_t offset, size_t length)
 
     if (offset == 0) { 
 	if (length > src->length ) {
-	    if (lseek (src->fd, length * src->bps, SEEK_SET) == -1)
+	    if (lseek (src->fd, length * src->bps - 1, SEEK_SET) == -1)
 		g_warning ("lseek: %s", g_strerror (errno));
 	    
 	    /* it's necessary to write to the end of the file
